@@ -281,7 +281,8 @@ public:
         imageIdleWatcher(2000 /*ms*/),
         kraLoader(0),
         suppressProgress(false),
-        fileProgressProxy(0)
+        fileProgressProxy(0),
+        savingLock(&savingMutex)
     {
         if (QLocale().measurementSystem() == QLocale::ImperialSystem) {
             unit = KoUnit::Inch;
@@ -378,6 +379,8 @@ public:
     QList<KisPaintingAssistantSP> assistants;
     KisGridConfig gridConfig;
 
+    StdLockableWrapper<QMutex> savingLock;
+
     bool openFile() {
         document->setFileProgressProxy();
         document->setUrl(m_url);
@@ -439,6 +442,69 @@ public:
     class SafeSavingLocker;
 };
 
+class KisDocument::Private::SafeSavingLocker {
+public:
+    SafeSavingLocker(KisDocument::Private *_d)
+        : d(_d),
+          m_locked(false),
+          m_imageLock(d->image, true)
+    {
+        const int realAutoSaveInterval = KisConfig().autoSaveInterval();
+        const int emergencyAutoSaveInterval = 10; // sec
+
+        /**
+         * Initial try to lock both objects. Locking the image guards
+         * us from any image composition threads running in the
+         * background, while savingMutex guards us from entering the
+         * saving code twice by autosave and main threads.
+         *
+         * Since we are trying to lock multiple objects, so we should
+         * do it in a safe manner.
+         */
+        m_locked = std::try_lock(m_imageLock, d->savingLock) < 0;
+
+        if (!m_locked) {
+            if (d->isAutosaving) {
+                d->disregardAutosaveFailure = true;
+                if (realAutoSaveInterval) {
+                    d->document->setAutoSave(emergencyAutoSaveInterval);
+                }
+            } else {
+                d->image->requestStrokeEnd();
+                QApplication::processEvents();
+
+                // one more try...
+                m_locked = std::try_lock(m_imageLock, d->savingLock) < 0;
+            }
+        }
+
+        if (m_locked) {
+            d->disregardAutosaveFailure = false;
+        }
+    }
+
+    ~SafeSavingLocker() {
+         if (m_locked) {
+             m_imageLock.unlock();
+             d->savingLock.unlock();
+
+             const int realAutoSaveInterval = KisConfig().autoSaveInterval();
+             d->document->setAutoSave(realAutoSaveInterval);
+         }
+     }
+
+    bool successfullyLocked() const {
+        return m_locked;
+    }
+
+private:
+    KisDocument::Private *d;
+    bool m_locked;
+
+    KisImageBarrierLockAdapter m_imageLock;
+};
+
+
 KisDocument::KisDocument()
     : d(new Private(this))
 {
@@ -636,9 +702,11 @@ bool KisDocument::saveFile(KisPropertiesConfigurationSP exportConfiguration)
 
     if (!isNativeFormat(outputMimeType)) {
 
-        d->savingImage = d->image->clone(true);
+        if (!prepareLocksForSaving()) {
+            return false;
+        }
         status = d->importExportManager->exportDocument(tempororaryFileName, outputMimeType, exportConfiguration);
-        d->savingImage.clear();
+        unlockAfterSaving();
 
         ret = status == KisImportExportFilter::OK;
         suppressErrorDialog = (status == KisImportExportFilter::UserCancelled || status == KisImportExportFilter::BadConversionGraph);
@@ -872,9 +940,44 @@ bool KisDocument::isModified() const
     return d->modified;
 }
 
+bool KisDocument::prepareLocksForSaving()
+{
+    {
+        Private::SafeSavingLocker locker(d);
+        if (locker.successfullyLocked()) {
+            d->savingImage = d->image->clone(true);
+        }
+        else {
+            d->lastErrorMessage = i18n("The image was still busy while saving. Your saved image might be incomplete.");
+            d->image->lock();
+            d->savingImage = d->image->clone(true);
+            d->image->unlock();
+        }
+    }
+
+    if (!d->savingMutex.tryLock()) {
+        qWarning() << "Could not lock for saving!";
+        d->lastErrorMessage = i18n("Could not lock the image for saving.");
+        d->savingImage = 0;
+        return false;
+    }
+
+    Q_ASSERT(d->savingImage);
+    return true;
+}
+
+void KisDocument::unlockAfterSaving()
+{
+    d->savingImage = 0;
+    d->savingMutex.unlock();
+}
+
 bool KisDocument::saveNativeFormat(const QString & file)
 {
-    d->savingImage = d->image->clone(true);
+    if (!prepareLocksForSaving()) {
+        return false;
+    }
+
     d->lastErrorMessage.clear();
     //dbgUI <<"Saving to store";
 
@@ -889,10 +992,10 @@ bool KisDocument::saveNativeFormat(const QString & file)
         if (f.open(QIODevice::WriteOnly | QIODevice::Text)) {
             bool success = saveToStream(&f);
             f.close();
-            d->savingImage = 0;
+            unlockAfterSaving();
             return success;
         } else {
-            d->savingImage = 0;
+            unlockAfterSaving();
             return false;
         }
     }
@@ -907,7 +1010,7 @@ bool KisDocument::saveNativeFormat(const QString & file)
     }
     if (store->bad()) {
         d->lastErrorMessage = i18n("Could not create the file for saving");   // more details needed?
-        d->savingImage = 0;
+        unlockAfterSaving();
         delete store;
         return false;
     }
@@ -916,15 +1019,29 @@ bool KisDocument::saveNativeFormat(const QString & file)
 
     if (!d->isAutosaving) {
         KisAsyncActionFeedback f(i18n("Saving document..."), 0);
-        result = f.runAction(std::bind(&KisDocument::saveNativeFormatCalligra, this, store));
+        result = f.runAction(std::bind(&KisDocument::saveNativeFormatCalligraImpl, this, store));
     } else {
-        result = saveNativeFormatCalligra(store);
+        result = saveNativeFormatCalligraImpl(store);
     }
-    d->savingImage = 0;
+    unlockAfterSaving();
     return result;
 }
 
-bool KisDocument::saveNativeFormatCalligra(KoStore *store)
+bool KisDocument::saveNativeFormatCalligraDirect(KoStore *store)
+{
+    bool result = false;
+
+    Private::SafeSavingLocker locker(d);
+    if (locker.successfullyLocked()) {
+        d->savingImage = d->image;
+        result = saveNativeFormatCalligraImpl(store);
+        d->savingImage = 0;
+    }
+
+    return result;
+}
+
+bool KisDocument::saveNativeFormatCalligraImpl(KoStore *store)
 {
     dbgUI << "Saving root";
     if (store->open("root")) {
@@ -1104,7 +1221,6 @@ bool KisDocument::importDocument(const QUrl &_url)
 bool KisDocument::openUrl(const QUrl &_url, KisDocument::OpenUrlFlags flags)
 {
     if (!_url.isLocalFile()) {
-        qDebug() << "not a local file" << _url;
         return false;
     }
     dbgUI << "url=" << _url.url();
@@ -1722,7 +1838,6 @@ bool KisDocument::completeLoading(KoStore* store)
 
 bool KisDocument::completeSaving(KoStore* store)
 {
-    Q_ASSERT(!d->savingImage.isNull());
     d->kraSaver->saveKeyframes(store, url().url(), isStoredExtern());
     d->kraSaver->saveBinaryData(store, d->savingImage, url().url(), isStoredExtern(), d->isAutosaving);
     bool retval = true;
@@ -1838,8 +1953,6 @@ QDomDocument KisDocument::saveXML()
     if (d->kraSaver) delete d->kraSaver;
     d->kraSaver = new KisKraSaver(this);
 
-    Q_ASSERT(!d->savingImage.isNull());
-
     root.appendChild(d->kraSaver->saveXML(doc, d->savingImage));
     if (!d->kraSaver->errorMessages().isEmpty()) {
         setErrorMessage(d->kraSaver->errorMessages().join(".\n"));
