@@ -98,6 +98,7 @@
 #include <KisMimeDatabase.h>
 #include <brushengine/kis_paintop_settings.h>
 #include "dialogs/kis_about_application.h"
+#include "dialogs/kis_delayed_save_dialog.h"
 #include "dialogs/kis_dlg_preferences.h"
 #include "kis_action.h"
 #include "kis_action_manager.h"
@@ -881,8 +882,11 @@ bool KisMainWindow::saveDocument(KisDocument *document, bool saveas, bool silent
     std::unique_lock<StdLockableWrapper<QMutex>> l(wrapper, std::try_to_lock);
     if (!l.owns_lock()) return false;
 
-    if (!document->image()->isIdle()) {
-        QMessageBox::warning(this, i18nc("@title:window", "Krita"), i18n("Krita is still rendering the last strokes. Those strokes will not be saved."));
+    KisDelayedSaveDialog dlg(document->image(), this);
+    dlg.blockIfImageIsBusy();
+
+    if (dlg.result() != QDialog::Accepted) {
+        return false;
     }
 
     bool reset_url;
