@@ -55,7 +55,6 @@ public:
         CurrentPattern,
         CurrentGradient,
         CurrentDisplayProfile,
-        CurrentImage,
         CurrentKritaNode,
         CurrentPaintOpPreset,
         CurrentGeneratorConfiguration,
@@ -69,7 +68,6 @@ public:
         MirrorVerticalLock,
         MirrorVerticalHideDecorations,
         MirrorHorizontalHideDecorations,
-        MirrorAxesCenter,
         Opacity,
         Flow,
         Size,
