@@ -34,7 +34,7 @@ public:
     QMLConverter();
     virtual ~QMLConverter();
 public:
-    KisImageBuilder_Result buildFile(const QString &filename, KisImageWSP image);
+    KisImageBuilder_Result buildFile(const QString &filename, KisImageSP image);
 
 private:
     void writeString(QTextStream& out, int spacing, const QString& setting, const QString& value);
