@@ -27,6 +27,8 @@
 #include "KisMainWindow.h"
 #include "KisViewManager.h"
 
+#include "kis_transform_utils.h"
+
 
 template<typename T> inline T sign(T x) {
     return x > 0 ? 1 : x == (T)0 ? 0 : -1;
@@ -539,19 +541,19 @@ void KisToolTransformConfigWidget::updateConfig(const ToolTransformArgs &config)
         aXBox->setEnabled(freeTransformIsActive);
         aYBox->setEnabled(freeTransformIsActive);
         aZBox->setEnabled(freeTransformIsActive);
-        Q_FOREACH (QAbstractButton *button, m_rotationCenterButtons->buttons()) {
-            button->setEnabled(freeTransformIsActive);
-            freeRotationRadioButton->setEnabled(freeTransformIsActive);
-        }
+        freeRotationRadioButton->setEnabled(freeTransformIsActive);
 
         scaleXBox->setValue(config.scaleX() * 100.);
         scaleYBox->setValue(config.scaleY() * 100.);
         shearXBox->setValue(config.shearX());
         shearYBox->setValue(config.shearY());
 
-        translateXBox->setValue(config.transformedCenter().x());
-        translateYBox->setValue(config.transformedCenter().y());
+        const QPointF anchorPoint = config.originalCenter() + config.rotationCenterOffset();
+        const KisTransformUtils::MatricesPack m(config);
+        const QPointF anchorPointView = m.finalTransform().map(anchorPoint);
 
+        translateXBox->setValue(anchorPointView.x());
+        translateYBox->setValue(anchorPointView.y());
 
         aXBox->setValue(radianToDegree(config.aX()));
         aYBox->setValue(radianToDegree(config.aY()));
@@ -838,7 +840,10 @@ void KisToolTransformConfigWidget::slotRotationCenterChanged(int index)
                                                 j * m_transaction->originalHalfHeight()));
 
         notifyConfigChanged();
+        updateConfig(*config);
     }
+
+
 }
 
 void KisToolTransformConfigWidget::slotSetScaleX(int value)
@@ -911,7 +916,14 @@ void KisToolTransformConfigWidget::slotSetTranslateX(int value)
     if (m_uiSlotsBlocked) return;
 
     ToolTransformArgs *config = m_transaction->currentConfig();
-    config->setTransformedCenter(QPointF(value, config->transformedCenter().y()));
+
+    const QPointF anchorPoint = config->originalCenter() + config->rotationCenterOffset();
+    const KisTransformUtils::MatricesPack m(*config);
+
+    const QPointF anchorPointView = m.finalTransform().map(anchorPoint);
+    const QPointF newAnchorPointView(value, anchorPointView.y());
+    config->setTransformedCenter(config->transformedCenter() + newAnchorPointView - anchorPointView);
+
     notifyConfigChanged();
 }
 
@@ -920,7 +932,14 @@ void KisToolTransformConfigWidget::slotSetTranslateY(int value)
     if (m_uiSlotsBlocked) return;
 
     ToolTransformArgs *config = m_transaction->currentConfig();
-    config->setTransformedCenter(QPointF(config->transformedCenter().x(), value));
+
+    const QPointF anchorPoint = config->originalCenter() + config->rotationCenterOffset();
+    const KisTransformUtils::MatricesPack m(*config);
+
+    const QPointF anchorPointView = m.finalTransform().map(anchorPoint);
+    const QPointF newAnchorPointView(anchorPointView.x(), value);
+    config->setTransformedCenter(config->transformedCenter() + newAnchorPointView - anchorPointView);
+
     notifyConfigChanged();
 }
 
